#pragma once

#include <string>
#include <thread>
#include <mutex>
#include <condition_variable>
#include <drogon/HttpClient.h>
#include <trantor/net/EventLoop.h>

struct HttpResponse {
    int status_code;
    std::string body;
    bool success;
};

// SSL configuration options for HTTP client
struct HttpClientSSLConfig {
    std::string cert_path;      // Client certificate path
    std::string key_path;       // Client key path
    bool validate_cert = true;  // Whether to validate server certificate
    bool use_old_tls = false;   // Enable TLS 1.0/1.1
    std::vector<std::pair<std::string, std::string>> ssl_configs; // Additional SSL_CONF_cmd options
};

// Utility function for blocking HTTP GET requests
HttpResponse http_get(const std::string& url, const std::string& path, bool use_https = false, double timeout_seconds = 10.0);

// Utility function for blocking HTTP GET requests with SSL configuration
HttpResponse http_get_with_ssl(const std::string& url, const std::string& path, const HttpClientSSLConfig& ssl_config, double timeout_seconds = 10.0);